@@ -7,12 +7,12 @@
 #######################################################################
 """Inrefaces for the Zope 3 based smartimagecache package
 
-$Id: interfaces.py 35337 2008-05-28 09:01:39Z cray $
+$Id: interfaces.py 35338 2008-06-12 18:42:18Z anatoly $
 """
 __author__  = "Anatoly Bubenkov"
 __license__ = "ZPL"
-__version__ = "$Revision: 35337 $"
-__date__ = "$Date: 2008-05-28 13:01:39 +0400 (Срд, 28 Май 2008) $"
+__version__ = "$Revision: 35338 $"
+__date__ = "$Date: 2008-06-12 21:42:18 +0300 (Thu, 12 Jun 2008) $"
 
 from zope.schema.interfaces import IObject
 from zope.schema import TextLine
@@ -22,4 +22,6 @@ class ISmartImageField(IObject):
     """Smart Image Field"""
 
     scale = TextLine()
-    
\ No newline at end of file
+
+class ISmartImageParent(Interface):
+    """Smart Image Parent"""
