@@ -7,13 +7,13 @@
 #######################################################################
 """SmartImageDisplayWidget class for the Zope 3 based ks.widget package
 
-$Id: smartimagedisplaywidget.py 35337 2008-05-28 09:01:39Z cray $
+$Id: smartimagedisplaywidget.py 35338 2008-06-12 18:42:18Z anatoly $
 """
 
 __author__  = "Anatoly Orlov"
-__license__ = "ZPL" 
-__version__ = "$Revision: 35337 $"
-__date__ = "$Date: 2008-05-28 13:01:39 +0400 (Срд, 28 Май 2008) $"
+__license__ = "ZPL"
+__version__ = "$Revision: 35338 $"
+__date__ = "$Date: 2008-06-12 21:42:18 +0300 (Thu, 12 Jun 2008) $"
 __credits__ = "Based heavily on Anatoly Bubenkov sources"
 
 from zope.interface import implements
@@ -23,6 +23,7 @@ from zope.app.form.browser.widget import DisplayWidget
 from zope.component import getMultiAdapter
 from zope.security.proxy import getObject
 from imagedisplay import ImageDisplay
+from zope.app.form.browser.widget import renderElement
 
 
 class SmartImageDisplayWidget(ImageDisplay, DisplayWidget):
@@ -37,6 +38,7 @@ class SmartImageDisplayWidget(ImageDisplay, DisplayWidget):
             value = self.context.default
         if value == self.context.missing_value:
             return ""
-                    
-        return self.imagedisplay(value)
-        
\ No newline at end of file
+
+        return renderElement('a', href=self.imageurl(value),
+                             contents=self.imagedisplay(value),
+                             id=self.name)
